pub struct BuildContext { /* private fields */ }Expand description
Shared build context passed to all runners.
Carries environment variables and a metrics handle that runners use during task construction.
Created once at router setup time and shared (by clone) across all Runner::build_task calls.
Defaults
env: emptyRunnerEnvmetrics:NoOpMetrics(zero-cost)
Also
RunnerRouter::with_contextsets the context for all runners.MetricsHandle-Arc<dyn MetricsBackend>.
Implementations
Sourceimpl BuildContext
impl BuildContext
Sourcepub fn new(env: RunnerEnv, metrics: MetricsHandle) -> Self
pub fn new(env: RunnerEnv, metrics: MetricsHandle) -> Self
Create a new build context with the given params.
Sourcepub fn metrics(&self) -> &MetricsHandle
pub fn metrics(&self) -> &MetricsHandle
Get a clonable handle to the metrics backend.
Sourcepub fn with_env(self, env: RunnerEnv) -> Self
pub fn with_env(self, env: RunnerEnv) -> Self
Replace the environment and return updated context.
Sourcepub fn with_metrics(self, metrics: MetricsHandle) -> Self
pub fn with_metrics(self, metrics: MetricsHandle) -> Self
Replace the metrics backend and return updated context.